/// <reference types="node" />
import { Market } from '@project-serum/serum';
import { Pool } from '../accounts';
import { Fills, OrderbookListenerCB, ParsedOrderbook } from '../types';
import { CypherClient } from '../client/index';
import { PublicKey } from '@solana/web3.js';
export declare class SpotMarketViewer {
    readonly client: CypherClient;
    readonly pool: Pool;
    private _bidsListener;
    private _asksListener;
    private _eventQueueListener;
    private _openOrdersAccountListener;
    constructor(client: CypherClient, pool: Pool);
    private get connection();
    get market(): Market;
    orderbookParser(data: Buffer, orderbookDepth?: number): ParsedOrderbook;
    addBidsListener(callback: OrderbookListenerCB, orderbookDepth?: number): any;
    removeBidsListener(): void;
    addAsksListener(callback: OrderbookListenerCB, orderbookDepth?: number): any;
    removeAsksListener(): void;
    addEventQueueListener(callback: () => void): any;
    removeEventQueueListener(): void;
    addOpenOrdersAccountListener(openOrdersAccount: PublicKey, callback: () => void): any;
    removeOpenOrdersAccountListener(): void;
    calcMarketOrderPrice(size: number, side: 'buy' | 'sell', bids: ParsedOrderbook, asks: ParsedOrderbook): number;
    calcMarketOrderPriceForAvailableAmount(size: number, side: 'buy' | 'sell', bids: ParsedOrderbook, asks: ParsedOrderbook): number[];
    getTopAskPrice(asks: ParsedOrderbook): number;
    getlastPrice(fills: Fills): number;
    getMiddlePointPrice(bids: ParsedOrderbook, asks: ParsedOrderbook): number;
    getContractsOnOrderbooks(bids: ParsedOrderbook, asks: ParsedOrderbook): number;
    getOrderBook(): Promise<{
        bids: ParsedOrderbook;
        asks: ParsedOrderbook;
    }>;
    loadFills(): Promise<Fills>;
}
